@@ -1,5 +1,5 @@
 import click
-import os
+import os, shutil
 import re
 import sys
 import subprocess
@@ -61,6 +61,10 @@ def cli():
 
     dsf-cli run-server
 
+    create deploy files
+
+    dsf-cli create-deploy-files
+
     """
 # @click.option("--type", prompt="type", help="type of component")
 # @click.option("--project_name", prompt="project_name", help="project_name")
@@ -87,14 +91,18 @@ def run_server():
     folder = currentPipelineFolder + '/server/server.py'
     subprocess.call('python ' + folder, shell=True)
 
+@cli.command()
+def create_deploy_files():
+    copy_deploy_files('')
+
 ALIASES = {
     "g": generate
 }
 
-def generate_project(projectName):
-    projectName = clean_name(projectName)
-    click.echo('project generated ' + projectName)
-    create_project(projectName)
+def generate_project(project_name):
+    # project_name = clean_name(project_name)
+    click.echo('project generated ' + project_name)
+    create_project(project_name)
 
 def generate_forcer(fileName):
     fileName = clean_name(fileName)
@@ -108,9 +116,9 @@ def clean_name(name):
     name = name.replace('-', '_')
     return name
 
-def create_folders(projectName):
+def create_folders(project_name):
     global directories
-    directories['main'] = projectName + '_project'
+    directories['main'] = project_name
     if not os.path.exists(directories['main']):
         os.mkdir(directories['main'])
 
@@ -129,33 +137,36 @@ def create_folders(projectName):
     create_main_folders('trainer', 'main')
     create_main_folders('server', 'main')
 
-def create_project(projectName):
-    create_folders(projectName)
-    create_pipeline_file(projectName, directories['artifacts'], 'shared_artifacts')
-    create_pipeline_file(projectName, directories['schema'], 'inputs')
-    create_pipeline_file(projectName, directories['schema'], 'outputs')
-    create_pipeline_file(projectName, directories['preprocessor'], 'preprocess')
-    create_pipeline_file(projectName, directories['predictors'], 'predictor')
-    create_pipeline_file(projectName, directories['forcers'], 'forcer')
-    create_pipeline_file(projectName, directories['postprocessor'], 'postprocess')
-    create_pipeline_file(projectName, directories['predictables'], 'predictable')
-    create_pipeline_file(projectName, directories['pipeline'], 'pipeline')
-    create_pipeline_file(projectName, directories['main'], 'test_pipeline', False)
-    # create_tester_file(projectName, directories['tester'], 'tester')
-    # create_tester_file(projectName, directories['tester'], 'reporter')
-    create_tester_file(projectName, directories['server'], 'server', False)
-    create_tester_file(projectName, directories['server'], 'test_server_post', False)
-    # create_tester_file(projectName, directories['trainer'], 'trainer')
-    # create_pipeline_file(projectName, 'labelizer')
-    # create_pipeline_file(projectName, 'pipeline')
+def create_project(project_name):
+    create_folders(project_name)
+    project_name = clean_name(project_name)
+    create_pipeline_file(project_name, directories['artifacts'], 'shared_artifacts')
+    create_pipeline_file(project_name, directories['schema'], 'inputs')
+    create_pipeline_file(project_name, directories['schema'], 'outputs')
+    create_pipeline_file(project_name, directories['preprocessor'], 'preprocess')
+    create_pipeline_file(project_name, directories['predictors'], 'predictor')
+    create_pipeline_file(project_name, directories['forcers'], 'forcer')
+    create_pipeline_file(project_name, directories['postprocessor'], 'postprocess')
+    create_pipeline_file(project_name, directories['predictables'], 'predictable')
+    create_pipeline_file(project_name, directories['pipeline'], 'pipeline')
+    create_pipeline_file(project_name, directories['main'], 'test_pipeline', False)
+    # create_tester_file(project_name, directories['tester'], 'tester')
+    # create_tester_file(project_name, directories['tester'], 'reporter')
+    create_tester_file(project_name, directories['server'], 'server', False)
+    create_tester_file(project_name, directories['server'], 'test_server_post', False)
+    # create_tester_file(project_name, directories['trainer'], 'trainer')
+    # create_pipeline_file(project_name, 'labelizer')
+    # create_pipeline_file(project_name, 'pipeline')
     #
     create_project_config_json()
+    create_project_gitignore()
     create_server_config_json()
+    # copy_deploy_files(directories['main'])
     #
-    # create_tester_file(projectName, 'dataset')
-    # create_tester_file(projectName, 'reporter')
-    # create_tester_file(projectName, 'tester')
-    # create_tester_file(projectName, 'tester_server')
+    # create_tester_file(project_name, 'dataset')
+    # create_tester_file(project_name, 'reporter')
+    # create_tester_file(project_name, 'tester')
+    # create_tester_file(project_name, 'tester_server')
 
 
 def create_main_folders(targetDir, baseDir):
@@ -164,14 +175,14 @@ def create_main_folders(targetDir, baseDir):
     if not os.path.exists(directories[targetDir]):
         os.mkdir(directories[targetDir])
 
-def create_pipeline_file(projectName, folder, pipelineType, createInitFile=True):
+def create_pipeline_file(project_name, folder, pipelineType, createInitFile=True):
     data = read_template_file(pipelineType)
-    replace_in_template_and_create_file(projectName, folder, pipelineType, data, createInitFile)
+    replace_in_template_and_create_file(project_name, folder, pipelineType, data, createInitFile)
 
 
-def create_tester_file(projectName, folder, pipelineType, createInitFile=True):
+def create_tester_file(project_name, folder, pipelineType, createInitFile=True):
     data = read_template_file('tester/' + pipelineType)
-    replace_in_template_and_create_file(projectName, folder, pipelineType, data, createInitFile)
+    replace_in_template_and_create_file(project_name, folder, pipelineType, data, createInitFile)
 
 def create_exist_pipeline_file(type, fileName):
     pipelineType = type + 's'
@@ -212,11 +223,11 @@ def write_to_file(file_path, data):
         file.write(data)
         file.close()
 
-def replace_in_template_and_create_file(projectName, folder, pipelineType, data, createInitFile):
-    pipelineTypeNoUnderscore = to_capitalize_no_underscore(pipelineType)
-    projectNameNoUnderscore = to_capitalize_no_underscore(projectName)
-    className = projectNameNoUnderscore + pipelineTypeNoUnderscore
-    classNameForBaseObject = projectNameNoUnderscore + pipelineTypeNoUnderscore
+def replace_in_template_and_create_file(project_name, folder, pipelineType, data, createInitFile):
+    pipeline_type_no_underscore = to_capitalize_no_underscore(pipelineType)
+    project_name_no_underscore = to_capitalize_no_underscore(project_name)
+    className = project_name_no_underscore + pipeline_type_no_underscore
+    classNameForBaseObject = project_name_no_underscore + pipeline_type_no_underscore
     currentDir = folder.replace('/', '.')
     currentDirNoMainDir = folder.replace(directories['main'] + '/', '').replace('/', '.')
     currentBaseDir = directories['main'].replace('/', '.')
@@ -224,7 +235,7 @@ def replace_in_template_and_create_file(projectName, folder, pipelineType, data,
 
     data = data.replace('generatedClassName', classNameForBaseObject)
     data = data.replace('generatedClass', className)
-    data = data.replace('generatedProjectName', projectNameNoUnderscore)
+    data = data.replace('generatedProjectName', project_name_no_underscore)
     data = data.replace('generatedDirectory', currentDir)
     data = data.replace('generatedBaseDir', currentBaseDir)
     data = data.replace('generatedPipelineDir', currentPipelineDir)
@@ -362,6 +373,15 @@ def create_project_config_json():
             f.write(data)
             f.close()
 
+def create_project_gitignore():
+    with open(os.path.join(__location__, 'cli/.gitignore'), 'r') as file:
+        data = file.read()
+        new_file = directories['main'] + '/.gitignore'
+        if not os.path.exists(new_file):
+            f = open(new_file, "w")
+            f.write(data)
+            f.close()
+
 def create_server_config_json():
     with open(os.path.join(__location__, 'cli/cors_allowed_origins.json'), 'r') as file:
         data = file.read()
@@ -372,6 +392,32 @@ def create_server_config_json():
             f.write(data)
             f.close()
 
+def copy_deploy_files(main_dir):
+    currentPipelineFolder = os.path.basename(os.getcwd())
+    dir = os.path.join(__location__, main_dir, 'cli/tester/deploy_files/')
+    listOfFiles = list()
+    for (dirpath, dirname, filenames) in os.walk(dir):
+        dirpath = dirpath.replace(dir, '')
+        listOfFiles += [os.path.join(dirpath, file) for file in filenames]
+        for file_path in listOfFiles:
+            with open(os.path.join(dir, file_path), 'r') as file:
+                data = file.read()
+                data = data.replace('{name-your-service}', currentPipelineFolder)
+                data = data.replace('{name-your-artifacts}', currentPipelineFolder)
+                if not os.path.exists('deploy'):
+                    os.makedirs('deploy')
+                if not os.path.exists(file_path):
+                    f = open(file_path, "w")
+                    f.write(data)
+                    f.close()
+    # for item in os.listdir(dir):
+    #     s = os.path.join(dir, item)
+    #     d = os.path.join(main_dir, item)
+    #     if os.path.isdir(s):
+    #         shutil.copytree(s, d, False, None)
+    #     else:
+    #         shutil.copy2(s, d)
+
 def to_capitalize_no_underscore(text):
     return ''.join(elem.capitalize() for elem in text.split('_'))
 
